==> prestashop_1.3.0.3.zip: prestashop/modules/statsregistrations/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Cuenstas cliente';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_54c04cc0d869c12ea9f5426466d40fea'] = 'Mostrar la progresión de la suscripción cliente';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'Visitantes que no han pasado de la suscripción:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_0d298316c16a0bbdb74d50ead21590b4'] = 'Visitantes que han efectuado un pedido directamente después de suscribirse:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Total cuentas cliente:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guía';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Número de clientes que han creado una cuenta';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_15d820295ae2d9d7e6d53e1ed9714273'] = 'El número total de cuentas creadas no es en sí misma información importante. Sin embargo, es interesante analizar la cantidad creada en un cierto plazo. Esto indicará de una manera u otra  si las cosas van por buen camino.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = '¿Cómo intervenir en la evolución de las suscripciones?';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_2d8c349a97131b417bf7da166afb17bd'] = 'i usted deja su tienda funcionar sin realizar cambios, el número de suscripciones de cliente puede permanecer estable o declinar levemente.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_bf88699f842b6e63e0568ed0e71c68b7'] = 'Un aumento significativo o una disminución demuestra que ha habido probablemente un cambio en su tienda; por lo tanto,  usted debe identificarlo y dar marcha atrás si ha habido una disminución de suscripciones o continuar con él si es ventajoso.  ';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_7f93ad00e5438305b72efd723da48cdb'] = 'AquÃ­ se muestra un sumario de lo que puede afectar  a la hora de crear cuentas de clientes.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_c22f6af88c5ec8dcdba70e4fa394b08e'] = 'Una campaña publicitaria puede atraer un mayor número de visitantes.Un incremento de clientes registrados le dará cierta seguridad, pero depende de su \\\"calidad\\\": una publicidad bien dirigida puede resultar más efectiva que un campaña a gran escala.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_d140e86c9fd44c00ed1df75b92ce8115'] = 'Ofertas especiales, rebajas o contenidos crean grandes espectativas y curiosidad, así no sólo se mantiene activo su comercio activo sino que además aumenta el tráfico. De esta manera, puede captar clientes impulsivos.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_97d6defbec1f8cd01e8219da3e917a0b'] = 'El diseño y la accesibilidad son más importantes que nunca: una mala accesibilidad o una mala presentación gráfica puede hacer que sus visitantes se vayan. Tiene que crear un balance entre un diseño innovador que permita al visitante moverse por la red con comodidad. Un escritura clara y correcta también inspirarán más confianza para el cliente hacia su comercio.';

==> prestashop_1.3.2.3.zip: prestashop/modules/statsregistrations/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Cuentas cliente';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_54c04cc0d869c12ea9f5426466d40fea'] = 'Mostrar la progresión de la suscripción de clientes';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'Visitantes que no han pasado de la suscripción:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_0d298316c16a0bbdb74d50ead21590b4'] = 'Visitantes que han efectuado un pedido directamente después de suscribirse:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Total cuentas cliente:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guía';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Número de clientes que han creado una cuenta';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_15d820295ae2d9d7e6d53e1ed9714273'] = 'El número total de cuentas creadas no es en sí misma información importante. Sin embargo, es interesante analizar la cantidad creada en un cierto plazo. Esto indicará de una manera u otra  si las cosas van por buen camino.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = '¿Cómo intervenir en la evolución de las suscripciones?';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_2d8c349a97131b417bf7da166afb17bd'] = 'i usted deja su tienda funcionar sin realizar cambios, el número de suscripciones de cliente puede permanecer estable o declinar levemente.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_bf88699f842b6e63e0568ed0e71c68b7'] = 'Un aumento significativo o una disminución demuestra que ha habido probablemente un cambio en su tienda; por lo tanto,  usted debe identificarlo y dar marcha atrás si ha habido una disminución de suscripciones o continuar con él si es ventajoso.  ';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_7f93ad00e5438305b72efd723da48cdb'] = 'AquÃ­ se muestra un sumario de lo que puede afectar  a la hora de crear cuentas de clientes.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_c22f6af88c5ec8dcdba70e4fa394b08e'] = 'Una campaña publicitaria puede atraer un mayor número de visitantes.Un incremento de clientes registrados le dará cierta seguridad, pero depende de su \\\"calidad\\\": una publicidad bien dirigida puede resultar más efectiva que un campaña a gran escala.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_d140e86c9fd44c00ed1df75b92ce8115'] = 'Ofertas especiales, rebajas o contenidos crean grandes espectativas y curiosidad, así no sólo se mantiene activo su comercio activo sino que además aumenta el tráfico. De esta manera, puede captar clientes impulsivos.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_97d6defbec1f8cd01e8219da3e917a0b'] = 'El diseño y la accesibilidad son más importantes que nunca: una mala accesibilidad o una mala presentación gráfica puede hacer que sus visitantes se vayan. Tiene que crear un balance entre un diseño innovador que permita al visitante moverse por la red con comodidad. Un escritura clara y correcta también inspirarán más confianza para el cliente hacia su comercio.';
